2 ms·
> I'm probably doing something wrong. Yes, it turns out. :-) The "busy-*" programs just run the loops without doing any SQLite operations, in order to test lo
by mpweiher 5y ago
> I'm probably doing something wrong.
Yes, it turns out. :-)
The "busy-*" programs just run the loops without doing any SQLite operations, in order to test loop overhead.
On my M1 Air, this is the fastest time I get from Rust:
> ./bench-threaded-rust.sh
Sun Jul 25 07:52:46 CEST 2021 [RUST] threaded_batched.rs (100_000_000) inserts
real 0m20.765s
user 0m25.916s
sys 0m2.303s
- avinassh 5y agoAuthor of the code here and yes, that's correct! Also, it is possible that rust compiler might be optimising this code, remove the random generation calls altogether. (I haven't gotten around to doing the analysis, yet) I am surprised M1 Air taking 20 seconds, on my old machine its 7seconds ish.